---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'bug'
assignees: ''

---
## Long story short

<!-- Please describe your problem in 1-3 sentences. What has happened? What has not happened, but should have? -->


## Description

<!-- Please provide as much information as possible. Lack of information may result in a delayed response. As a guideline, use the following placeholders, and add yours as needed. -->

<details><summary>The code snippet to reproduce the issue</summary>

```python
import kopf
```
</details>

<details><summary>The exact command to reproduce the issue</summary>

```bash
kopf run ...
```
</details>

<details><summary>The full output of the command that failed</summary>

```
```
</details>


## Environment

<!-- The following commands can help:
     `kopf --version` or `pip show kopf`
     `kubectl version`
     `python --version`
-->

* Kopf version: 
* Kubernetes version: 
* Python version: 
* OS/platform: 

<details><summary>Python packages installed</summary>
<!-- use `pip freeze --all` -->

```
```
</details>

